<?php

namespace alldevs\IfocopBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM;

/**
 * Groupes
 * 
 * @ORM\Table(name="groupes")
 * @ORM\Entity(repositoryClass="alldevs\IfocopBundle\Entity\GroupesRepository")
 */
class Groupes
{
    /**
     * 
     * @ORM\Column(name="id", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $id;
    
    /**
     *  
     * @ORM\Column(name="lib", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(50)  
     */
    private $lib;

    /**
     * 
     * @ORM\Column(name="cde", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(9)  
     */
    private $cde;

    /**
     * 
     * @ORM\Column(name="typeannee", type="integer", nullable=true)
     */
    private $typeannee;

    /**
     * 
     * @ORM\Column(name="datedebut", type="datetime", nullable=true)
     * @Assert\DateTime()
     * @Assert\NotBlank()
     */
    private $datedebut;

    /**
     * 
     * @ORM\Column(name="datefin", type="datetime", nullable=true)
     * @Assert\DateTime()
     * @Assert\NotBlank()
     */
    private $datefin;

    /**
     * 
     * @ORM\Column(name="dateannee", type="integer", nullable=true)
     * @Assert\NotBlank()
     */
    private $dateannee;

    
    /**
     * 
     * @ORM\ManyToOne(targetEntity="Centres", inversedBy="idGroupes", cascade={"persist"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_centres", referencedColumnName="id")
     * })
     * @Assert\NotNull()
     */
    private $idCentres;

    /**
     *
     * @ORM\ManyToMany(targetEntity="Formations", inversedBy="idGroupes", cascade={"persist"})
     * @ORM\JoinTable(name="formations_groupes",
     * inverseJoinColumns={@ORM\JoinColumn(name="id_formations", referencedColumnName="id")},
     * joinColumns={@ORM\JoinColumn(name="id_groupes", referencedColumnName="id")}
     * ) 
     * @Assert\Count(min = "1")
     */   
    private $idFormations;
    
    /**
     * 
     * @ORM\Column(name="nbrheure", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(9) 
     */
    private $nbrheure;
   

    /**
     * @ORM\OneToMany(targetEntity="Stagiaires", mappedBy="idGroupes", cascade={"all"}, orphanRemoval=true)
     * @ORM\OrderBy({"nom" = "ASC"})
     */
    private $idStagiaires;

    /**
     * 
     * @ORM\Column(name="description", type="text", nullable=true)
     */
    private $description;
    
    public function __toString()
    {
            return $this->getLib();
    }

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idFormations = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idStagiaires = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Set id
     *
     * @param integer id
     * @return Groupes
     */
    public function setId($id)
    {
        $this->id = $id;
    
        return $this;
    }    
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set cs
     *
     * @param float $cs
     * @return Groupes
     */
    public function setCs($cs)
    {
        $this->cs = $cs;
    
        return $this;
    }

    /**
     * Get cs
     *
     * @return float 
     */
    public function getCs()
    {
        return $this->cs;
    }

    /**
     * Set di
     *
     * @param float $di
     * @return Groupes
     */
    public function setDi($di)
    {
        $this->di = $di;
    
        return $this;
    }

    /**
     * Get di
     *
     * @return float 
     */
    public function getDi()
    {
        return $this->di;
    }

    /**
     * Set comptedi
     *
     * @param string $comptedi
     * @return Groupes
     */
    public function setComptedi($comptedi)
    {
        $this->comptedi = $comptedi;
    
        return $this;
    }

    /**
     * Get comptedi
     *
     * @return string 
     */
    public function getComptedi()
    {
        return $this->comptedi;
    }

    /**
     * Set comptecs
     *
     * @param string $comptecs
     * @return Groupes
     */
    public function setComptecs($comptecs)
    {
        $this->comptecs = $comptecs;
    
        return $this;
    }

    /**
     * Get comptecs
     *
     * @return string 
     */
    public function getComptecs()
    {
        return $this->comptecs;
    }

    /**
     * Set lib
     *
     * @param string $lib
     * @return Groupes
     */
    public function setLib($lib)
    {
        $this->lib = $lib;
    
        return $this;
    }

    /**
     * Get lib
     *
     * @return string 
     */
    public function getLib()
    {
        return $this->lib;
    }

    /**
     * Set cde
     *
     * @param string $cde
     * @return Groupes
     */
    public function setCde($cde)
    {
        $this->cde = $cde;
    
        return $this;
    }

    /**
     * Get cde
     *
     * @return string 
     */
    public function getCde()
    {
        return $this->cde;
    }

    /**
     * Set typeannee
     *
     * @param integer $typeannee
     * @return Groupes
     */
    public function setTypeannee($typeannee)
    {
        $this->typeannee = $typeannee;
    
        return $this;
    }

    /**
     * Get typeannee
     *
     * @return integer 
     */
    public function getTypeannee()
    {
        return $this->typeannee;
    }

    /**
     * Set datedebut
     *
     * @param \DateTime $datedebut
     * @return Groupes
     */
    public function setDatedebut($datedebut)
    {
        $this->datedebut = $datedebut;
    
        return $this;
    }

    /**
     * Get datedebut
     *
     * @return \DateTime 
     */
    public function getDatedebut()
    {
        return $this->datedebut;
    }

    /**
     * Set datefin
     *
     * @param \DateTime $datefin
     * @return Groupes
     */
    public function setDatefin($datefin)
    {
        $this->datefin = $datefin;
    
        return $this;
    }

    /**
     * Get datefin
     *
     * @return \DateTime 
     */
    public function getDatefin()
    {
        return $this->datefin;
    }

    /**
     * Set nbrheure
     *
     * @param string $nbrheure
     * @return Groupes
     */
    public function setNbrheure($nbrheure)
    {
        $this->nbrheure = $nbrheure;
    
        return $this;
    }

    /**
     * Get nbrheure
     *
     * @return string 
     */
    public function getNbrheure()
    {
        return $this->nbrheure;
    }

    /**
     * Set description
     *
     * @param string $description
     * @return Groupes
     */
    public function setDescription($description)
    {
        $this->description = $description;
    
        return $this;
    }

    /**
     * Get description
     *
     * @return string 
     */
    public function getDescription()
    {
        return $this->description;
    }

    /**
     * Set idCentres
     *
     * @param \alldevs\IfocopBundle\Entity\Centres $idCentres
     * @return Groupes
     */
    public function setIdCentres(\alldevs\IfocopBundle\Entity\Centres $idCentres = null)
    {
        $this->idCentres = $idCentres;
    
        return $this;
    }

    /**
     * Get idCentres
     *
     * @return \alldevs\IfocopBundle\Entity\Centres 
     */
    public function getIdCentres()
    {
        return $this->idCentres;
    }

    /**
     * Add idFormations
     *
     * @param \alldevs\IfocopBundle\Entity\Formations $idFormations
     * @return Groupes
     */
    public function addIdFormation(\alldevs\IfocopBundle\Entity\Formations $idFormations)
    {
        $this->idFormations[] = $idFormations;
    
        return $this;
    }

    /**
     * Remove idFormations
     *
     * @param \alldevs\IfocopBundle\Entity\Formations $idFormations
     */
    public function removeIdFormation(\alldevs\IfocopBundle\Entity\Formations $idFormations)
    {
        $this->idFormations->removeElement($idFormations);
    }

    /**
     * Get idFormations
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdFormations()
    {
        return $this->idFormations;
    }

    /**
     * Add idStagiaires
     *
     * @param \alldevs\IfocopBundle\Entity\Stagiaires $idStagiaires
     * @return Groupes
     */
    public function addIdStagiaire(\alldevs\IfocopBundle\Entity\Stagiaires $idStagiaires)
    {
        $this->idStagiaires[] = $idStagiaires;
    
        return $this;
    }

    /**
     * Remove idStagiaires
     *
     * @param \alldevs\IfocopBundle\Entity\Stagiaires $idStagiaires
     */
    public function removeIdStagiaire(\alldevs\IfocopBundle\Entity\Stagiaires $idStagiaires)
    {
        $this->idStagiaires->removeElement($idStagiaires);
    }

    /**
     * Get idStagiaires
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdStagiaires()
    {
        return $this->idStagiaires;
    }

    /**
     * Set dateannee
     *
     * @param integer $dateannee
     * @return Groupes
     */
    public function setDateannee($dateannee)
    {
        $this->dateannee = $dateannee;
    
        return $this;
    }

    /**
     * Get dateannee
     *
     * @return integer 
     */
    public function getDateannee()
    {
        return $this->dateannee;
    }
}