<?php

namespace alldevs\IfocopBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM;

/**
 * Organismes
 * 
 * @ORM\Table(name="prises")
 * @ORM\Entity(repositoryClass="alldevs\IfocopBundle\Entity\PrisesRepository")
 */
class Prises
{
    /**
     *     
     * @ORM\Column(name="id", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $id;

    /**
     * @var float
     * @ORM\Column(name="montant", type="float", nullable=false)
     * @Assert\NotBlank()
     */
    private $montant;

    /**
     * @var float
     * @ORM\Column(name="coutheure", type="float", nullable=false)
     */
    private $coutheure;    
    
    /**
     * 
     * @ORM\ManyToOne(targetEntity="Moyen")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_moyen", referencedColumnName="id")
     * })
     * @Assert\NotNull() 
     */
    private $idMoyen;
    
    /**
     * 
     * @ORM\Column(name="description", type="text", nullable=true)
     */
    private $description;
    
    /**
     * 
     * @ORM\Column(name="dateprise", type="datetime", nullable=true)
     * @Assert\NotBlank()
     * @Assert\DateTime()
     */
    private $dateprise; 
    
    /**
     * 
     * @ORM\Column(name="dateprisefin", type="datetime", nullable=true)
     * @Assert\NotBlank()
     * @Assert\DateTime()
     */
    private $dateprisefin;     
    /**
     * 
     * @ORM\Column(name="typeannee", type="integer", nullable=true)
     */
    private $typeannee;

    /**
     * 
     * @ORM\Column(name="datedebut", type="datetime", nullable=true)
     * @Assert\DateTime()
     */
    private $datedebut;

    /**
     * 
     * @ORM\Column(name="datefin", type="datetime", nullable=true)
     * @Assert\DateTime()
     */
    private $datefin;
    
    /**
     * 
     * @ORM\Column(name="nbrheure", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(9) 
     */
    private $nbrheure;
    
    /**
     * 
     * @ORM\Column(name="reference", type="string", length=255, nullable=true)
     * @Assert\MaxLength(255) 
     */
    private $reference;
    
    /**
     * 
     * @ORM\Column(name="validation", type="boolean", nullable=true)
     */
    private $validation=0;
    
    /**
     * 
     * @ORM\Column(name="identstagiaire", type="string", length=255, nullable=true)
     * @Assert\MaxLength(255) 
     */
    private $identstagiaire;
    
    /**
     * @var \Groupes
     *
     * @ORM\ManyToOne(targetEntity="Groupes")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_groupes", referencedColumnName="id")
     * })
     * 
     */
    private $idGroupes;
    
    /**
     * @var \Stagiaires
     *
     * @ORM\ManyToOne(targetEntity="Stagiaires", inversedBy="idPrises", cascade={"persist"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_stagiaires", referencedColumnName="id")
     * })
     * @Assert\NotNull() 
     */
    private $idStagiaires;    
    
    /**
     * @var \Prises
     *
     * @ORM\OneToMany(targetEntity="Reglement", mappedBy="idPrises",cascade={"persist","remove"}, orphanRemoval=true)
     */
    private $idReglement;        
    
    /**
     * @var \Facture
     *
     * @ORM\OneToMany(targetEntity="Facture", mappedBy="idPrises",cascade={"persist","remove"}, orphanRemoval=true)
     */
    private $idFacture;  
    
    /**
     * @var \Organismes
     *
     * @ORM\ManyToOne(targetEntity="Organismes", inversedBy="idPrises")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_organismes", referencedColumnName="id")
     * })
     * @Assert\NotNull()
     */
    private $idOrganismes;

    public function __toString()
    {
            return $this->getIdOrganismes()->getLib();
    }


    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idReglement = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set lib
     *
     * @param string $lib
     * @return Prises
     */
    public function setLib($lib)
    {
        $this->lib = $lib;
    
        return $this;
    }

    /**
     * Get lib
     *
     * @return string 
     */
    public function getLib()
    {
        return $this->lib;
    }

    /**
     * Set montant
     *
     * @param float $montant
     * @return Prises
     */
    public function setMontant($montant)
    {
        $this->montant = $montant;
    
        return $this;
    }

    /**
     * Get montant
     *
     * @return float 
     */
    public function getMontant()
    {
        return $this->montant;
    }

    /**
     * Set description
     *
     * @param string $description
     * @return Prises
     */
    public function setDescription($description)
    {
        $this->description = $description;
    
        return $this;
    }

    /**
     * Get description
     *
     * @return string 
     */
    public function getDescription()
    {
        return $this->description;
    }

    /**
     * Set reference
     *
     * @param string $reference
     * @return Prises
     */
    public function setReference($reference)
    {
        $this->reference = $reference;
    
        return $this;
    }

    /**
     * Get reference
     *
     * @return string 
     */
    public function getReference()
    {
        return $this->reference;
    }

    /**
     * Set idMoyen
     *
     * @param \alldevs\IfocopBundle\Entity\Moyen $idMoyen
     * @return Prises
     */
    public function setIdMoyen(\alldevs\IfocopBundle\Entity\Moyen $idMoyen = null)
    {
        $this->idMoyen = $idMoyen;
    
        return $this;
    }

    /**
     * Get idMoyen
     *
     * @return \alldevs\IfocopBundle\Entity\Moyen 
     */
    public function getIdMoyen()
    {
        return $this->idMoyen;
    }

    /**
     * Set idGroupes
     *
     * @param \alldevs\IfocopBundle\Entity\Groupes $idGroupes
     * @return Prises
     */
    public function setIdGroupes(\alldevs\IfocopBundle\Entity\Groupes $idGroupes = null)
    {
        $this->idGroupes = $idGroupes;
    
        return $this;
    }

    /**
     * Get idGroupes
     *
     * @return \alldevs\IfocopBundle\Entity\Groupes 
     */
    public function getIdGroupes()
    {
        return $this->idGroupes;
    }

    /**
     * Set idStagiaires
     *
     * @param \alldevs\IfocopBundle\Entity\Stagiaires $idStagiaires
     * @return Prises
     */
    public function setIdStagiaires(\alldevs\IfocopBundle\Entity\Stagiaires $idStagiaires = null)
    {
        $this->idStagiaires = $idStagiaires;
    
        return $this;
    }

    /**
     * Get idStagiaires
     *
     * @return \alldevs\IfocopBundle\Entity\Stagiaires 
     */
    public function getIdStagiaires()
    {
        return $this->idStagiaires;
    }

    /**
     * Add idReglement
     *
     * @param \alldevs\IfocopBundle\Entity\Reglement $idReglement
     * @return Prises
     */
    public function addIdReglement(\alldevs\IfocopBundle\Entity\Reglement $idReglement)
    {
        $this->idReglement[] = $idReglement;
    
        return $this;
    }

    /**
     * Remove idReglement
     *
     * @param \alldevs\IfocopBundle\Entity\Reglement $idReglement
     */
    public function removeIdReglement(\alldevs\IfocopBundle\Entity\Reglement $idReglement)
    {
        $this->idReglement->removeElement($idReglement);
    }

    /**
     * Get idReglement
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdReglement()
    {
        return $this->idReglement;
    }

    /**
     * Set idOrganismes
     *
     * @param \alldevs\IfocopBundle\Entity\Organismes $idOrganismes
     * @return Prises
     */
    public function setIdOrganismes(\alldevs\IfocopBundle\Entity\Organismes $idOrganismes = null)
    {
        $this->idOrganismes = $idOrganismes;
    
        return $this;
    }

    /**
     * Get idOrganismes
     *
     * @return \alldevs\IfocopBundle\Entity\Organismes 
     */
    public function getIdOrganismes()
    {
        return $this->idOrganismes;
    }

    /**
     * Set dateprise
     *
     * @param \DateTime $dateprise
     * @return Prises
     */
    public function setDateprise($dateprise)
    {
        $this->dateprise = $dateprise;
    
        return $this;
    }

    /**
     * Get dateprise
     *
     * @return \DateTime 
     */
    public function getDateprise()
    {
        return $this->dateprise;
    }

    /**
     * Add idFacture
     *
     * @param \alldevs\IfocopBundle\Entity\Facture $idFacture
     * @return Prises
     */
    public function addIdFacture(\alldevs\IfocopBundle\Entity\Facture $idFacture)
    {
        $this->idFacture[] = $idFacture;
    
        return $this;
    }

    /**
     * Remove idFacture
     *
     * @param \alldevs\IfocopBundle\Entity\Facture $idFacture
     */
    public function removeIdFacture(\alldevs\IfocopBundle\Entity\Facture $idFacture)
    {
        $this->idFacture->removeElement($idFacture);
    }

    /**
     * Get idFacture
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdFacture()
    {
        return $this->idFacture;
    }

    /**
     * Set typeannee
     *
     * @param integer $typeannee
     * @return Prises
     */
    public function setTypeannee($typeannee)
    {
        $this->typeannee = $typeannee;
    
        return $this;
    }

    /**
     * Get typeannee
     *
     * @return integer 
     */
    public function getTypeannee()
    {
        return $this->typeannee;
    }

    /**
     * Set datedebut
     *
     * @param \DateTime $datedebut
     * @return Prises
     */
    public function setDatedebut($datedebut)
    {
        $this->datedebut = $datedebut;
    
        return $this;
    }

    /**
     * Get datedebut
     *
     * @return \DateTime 
     */
    public function getDatedebut()
    {
        return $this->datedebut;
    }

    /**
     * Set datefin
     *
     * @param \DateTime $datefin
     * @return Prises
     */
    public function setDatefin($datefin)
    {
        $this->datefin = $datefin;
    
        return $this;
    }

    /**
     * Get datefin
     *
     * @return \DateTime 
     */
    public function getDatefin()
    {
        return $this->datefin;
    }

    /**
     * Set nbrheure
     *
     * @param string $nbrheure
     * @return Prises
     */
    public function setNbrheure($nbrheure)
    {
        $this->nbrheure = $nbrheure;
    
        return $this;
    }

    /**
     * Get nbrheure
     *
     * @return string 
     */
    public function getNbrheure()
    {
        return $this->nbrheure;
    }

    /**
     * Set coutheure
     *
     * @param float $coutheure
     * @return Prises
     */
    public function setCoutheure($coutheure)
    {
        $this->coutheure = $coutheure;
    
        return $this;
    }

    /**
     * Get coutheure
     *
     * @return float 
     */
    public function getCoutheure()
    {
        return $this->coutheure;
    }

    /**
     * Set dateprisefin
     *
     * @param \DateTime $dateprisefin
     * @return Prises
     */
    public function setDateprisefin($dateprisefin)
    {
        $this->dateprisefin = $dateprisefin;
    
        return $this;
    }

    /**
     * Get dateprisefin
     *
     * @return \DateTime 
     */
    public function getDateprisefin()
    {
        return $this->dateprisefin;
    }

    /**
     * Set identstagiaire
     *
     * @param string $identstagiaire
     * @return Prises
     */
    public function setIdentstagiaire($identstagiaire)
    {
        $this->identstagiaire = $identstagiaire;
    
        return $this;
    }

    /**
     * Get identstagiaire
     *
     * @return string 
     */
    public function getIdentstagiaire()
    {
        return $this->identstagiaire;
    }

    /**
     * Set validation
     *
     * @param boolean $validation
     * @return Prises
     */
    public function setValidation($validation)
    {
        $this->validation = $validation;
    
        return $this;
    }

    /**
     * Get validation
     *
     * @return boolean 
     */
    public function getValidation()
    {
        return $this->validation;
    }
}