<?php

namespace alldevs\IfocopBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM;

/**
 * Stagiaires
 *  
 * @ORM\Table(name="stagiaires")
 * @ORM\Entity(repositoryClass="alldevs\IfocopBundle\Entity\StagiairesRepository")
 */
class Stagiaires
{
    /**
     *     
     * @ORM\Column(name="id", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $id;

    /**
     * 
     * @ORM\Column(name="nom", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(120)  
     */
    private $nom;

    /**
     *      
     * @ORM\Column(name="prenom", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(120)  
     */
    private $prenom;

    /**
     *   
     * @ORM\Column(name="adrrue", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     */
    private $adrrue;

    /**
     *   
     * @ORM\Column(name="adrville", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     */
    private $adrville;

    /**
     *      
     * @ORM\Column(name="adrcp", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(5)
     */
    private $adrcp;

    /**
     * 
     * @ORM\Column(name="telephone", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20) 
     */
    private $telephone;

    /**
     * 
     * @ORM\Column(name="fax", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20) 
     */
    private $fax;

    /**
     * 
     * @ORM\Column(name="email", type="string", length=100, nullable=true)
     * @Assert\MaxLength(75) 
     * @Assert\Email(
     *     message = "'{{ value }}' n'est pas un email valide."
     * ) 
     */
    private $email;  

    /**
     * 
     * @ORM\Column(name="gsm", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20) 
     */
    private $gsm;

    /**
     * 
     * @ORM\Column(name="nbrheure", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20) 
     */
    private $nbrheure;
    
    /**
     * 
     * @ORM\Column(name="typeannee", type="integer", nullable=true)
     */
    private $typeannee;

    /**
     * 
     * @ORM\Column(name="datedebut", type="datetime", nullable=true)
     * @Assert\DateTime()
     */
    private $datedebut;

    /**
     * 
     * @ORM\Column(name="datefin", type="datetime", nullable=true)
     * @Assert\DateTime()
     */
    private $datefin;
    
    /**
     * 
     * @ORM\Column(name="dateannee", type="integer", nullable=true)
     * 
     */
    private $dateannee;
    
    /**
     * @ORM\Column(name="cs", type="float", nullable=true)
     */
    private $cs=0;
    
    /**
     * @ORM\Column(name="di", type="float", nullable=true)
     */
    private $di=0;
    
    /**
     * @var string
     *
     * @ORM\Column(name="comptedi", type="string", nullable=true)
     */
    private $comptedi;    

    /**
     * @var string
     *
     * @ORM\Column(name="comptecs", type="string", nullable=true)
     */
    private $comptecs;       
    
    /**
     * @var \Prises
     *
     * @ORM\OneToMany(targetEntity="Prises", mappedBy="idStagiaires",cascade={"persist","remove"}, orphanRemoval=true)
     * 
     */
    private $idPrises;         

    /**
     * 
     * @ORM\Column(name="observation", type="text", nullable=true)
     */
    private $observation; 
    
    /**
     * @var \Groupes
     *
     * @ORM\ManyToOne(targetEntity="Groupes", inversedBy="idStagiaires")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_groupes", referencedColumnName="id")
     * })
     *  
     */
    private $idGroupes;
    
    /**
     * @var \Reglement
     *
     * @ORM\OneToMany(targetEntity="Reglement", mappedBy="idStagiaires",cascade={"persist","remove"}, orphanRemoval=true)
     * 
     */
    private $idReglement;      

    /**
     *
     * @ORM\ManyToOne(targetEntity="Formations")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_formations", referencedColumnName="id")
     * })
     * @Assert\NotNull()    
     */
    private $idFormations;
        
    /**
     * @var \Facture
     *
     * @ORM\OneToMany(targetEntity="Facture", mappedBy="idStagiaires",cascade={"persist","remove"}, orphanRemoval=true)
     * 
     */
    private $idFacture;  

    public function __toString()
    {
            return $this->getNom().' '.$this->getPrenom();        
    }      
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idPrises = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idReglement = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idFacture = new \Doctrine\Common\Collections\ArrayCollection();
    }
    /**
     * Set nom
     *
     * @param string $id
     * @return Stagiaires
     */
    public function setId($id)
    {
        $this->id = $id;
    
        return $this;
    }
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set nom
     *
     * @param string $nom
     * @return Stagiaires
     */
    public function setNom($nom)
    {
        $this->nom = $nom;
    
        return $this;
    }

    /**
     * Get nom
     *
     * @return string 
     */
    public function getNom()
    {
        return $this->nom;
    }

    /**
     * Set prenom
     *
     * @param string $prenom
     * @return Stagiaires
     */
    public function setPrenom($prenom)
    {
        $this->prenom = $prenom;
    
        return $this;
    }

    /**
     * Get prenom
     *
     * @return string 
     */
    public function getPrenom()
    {
        return $this->prenom;
    }

    /**
     * Set adrrue
     *
     * @param string $adrrue
     * @return Stagiaires
     */
    public function setAdrrue($adrrue)
    {
        $this->adrrue = $adrrue;
    
        return $this;
    }

    /**
     * Get adrrue
     *
     * @return string 
     */
    public function getAdrrue()
    {
        return $this->adrrue;
    }

    /**
     * Set adrville
     *
     * @param string $adrville
     * @return Stagiaires
     */
    public function setAdrville($adrville)
    {
        $this->adrville = $adrville;
    
        return $this;
    }

    /**
     * Get adrville
     *
     * @return string 
     */
    public function getAdrville()
    {
        return $this->adrville;
    }

    /**
     * Set adrcp
     *
     * @param string $adrcp
     * @return Stagiaires
     */
    public function setAdrcp($adrcp)
    {
        $this->adrcp = $adrcp;
    
        return $this;
    }

    /**
     * Get adrcp
     *
     * @return string 
     */
    public function getAdrcp()
    {
        return $this->adrcp;
    }

    /**
     * Set telephone
     *
     * @param string $telephone
     * @return Stagiaires
     */
    public function setTelephone($telephone)
    {
        $this->telephone = $telephone;
    
        return $this;
    }

    /**
     * Get telephone
     *
     * @return string 
     */
    public function getTelephone()
    {
        return $this->telephone;
    }

    /**
     * Set fax
     *
     * @param string $fax
     * @return Stagiaires
     */
    public function setFax($fax)
    {
        $this->fax = $fax;
    
        return $this;
    }

    /**
     * Get fax
     *
     * @return string 
     */
    public function getFax()
    {
        return $this->fax;
    }

    /**
     * Set email
     *
     * @param string $email
     * @return Stagiaires
     */
    public function setEmail($email)
    {
        $this->email = $email;
    
        return $this;
    }

    /**
     * Get email
     *
     * @return string 
     */
    public function getEmail()
    {
        return $this->email;
    }

    /**
     * Set gsm
     *
     * @param string $gsm
     * @return Stagiaires
     */
    public function setGsm($gsm)
    {
        $this->gsm = $gsm;
    
        return $this;
    }

    /**
     * Get gsm
     *
     * @return string 
     */
    public function getGsm()
    {
        return $this->gsm;
    }

    /**
     * Set nbreheure
     *
     * @param string $nbreheure
     * @return Stagiaires
     */
    public function setNbreheure($nbreheure)
    {
        $this->nbreheure = $nbreheure;
    
        return $this;
    }

    /**
     * Get nbreheure
     *
     * @return string 
     */
    public function getNbreheure()
    {
        return $this->nbreheure;
    }

    /**
     * Set cs
     *
     * @param float $cs
     * @return Stagiaires
     */
    public function setCs($cs)
    {
        $this->cs = $cs;
    
        return $this;
    }

    /**
     * Get cs
     *
     * @return float 
     */
    public function getCs()
    {
        return $this->cs;
    }

    /**
     * Set di
     *
     * @param float $di
     * @return Stagiaires
     */
    public function setDi($di)
    {
        $this->di = $di;
    
        return $this;
    }

    /**
     * Get di
     *
     * @return float 
     */
    public function getDi()
    {
        return $this->di;
    }

    /**
     * Set comptedi
     *
     * @param string $comptedi
     * @return Stagiaires
     */
    public function setComptedi($comptedi)
    {
        $this->comptedi = $comptedi;
    
        return $this;
    }

    /**
     * Get comptedi
     *
     * @return string 
     */
    public function getComptedi()
    {
        return $this->comptedi;
    }

    /**
     * Set comptecs
     *
     * @param string $comptecs
     * @return Stagiaires
     */
    public function setComptecs($comptecs)
    {
        $this->comptecs = $comptecs;
    
        return $this;
    }

    /**
     * Get comptecs
     *
     * @return string 
     */
    public function getComptecs()
    {
        return $this->comptecs;
    }

    /**
     * Set observation
     *
     * @param string $observation
     * @return Stagiaires
     */
    public function setObservation($observation)
    {
        $this->observation = $observation;
    
        return $this;
    }

    /**
     * Get observation
     *
     * @return string 
     */
    public function getObservation()
    {
        return $this->observation;
    }

    /**
     * Add idPrises
     *
     * @param \alldevs\IfocopBundle\Entity\Prises $idPrises
     * @return Stagiaires
     */
    public function addIdPrise(\alldevs\IfocopBundle\Entity\Prises $idPrises)
    {
        $this->idPrises[] = $idPrises;
    
        return $this;
    }

    /**
     * Remove idPrises
     *
     * @param \alldevs\IfocopBundle\Entity\Prises $idPrises
     */
    public function removeIdPrise(\alldevs\IfocopBundle\Entity\Prises $idPrises)
    {
        $this->idPrises->removeElement($idPrises);
    }

    /**
     * Get idPrises
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPrises()
    {
        return $this->idPrises;
    }

    /**
     * Set idCentres
     *
     * @param \alldevs\IfocopBundle\Entity\Centres $idCentres
     * @return Stagiaires
     */
    public function setIdCentres(\alldevs\IfocopBundle\Entity\Centres $idCentres = null)
    {
        $this->idCentres = $idCentres;
    
        return $this;
    }

    /**
     * Get idCentres
     *
     * @return \alldevs\IfocopBundle\Entity\Centres 
     */
    public function getIdCentres()
    {
        return $this->idCentres;
    }

    /**
     * Set idGroupes
     *
     * @param \alldevs\IfocopBundle\Entity\Groupes $idGroupes
     * @return Stagiaires
     */
    public function setIdGroupes(\alldevs\IfocopBundle\Entity\Groupes $idGroupes = null)
    {
        $this->idGroupes = $idGroupes;
    
        return $this;
    }

    /**
     * Get idGroupes
     *
     * @return \alldevs\IfocopBundle\Entity\Groupes 
     */
    public function getIdGroupes()
    {
        return $this->idGroupes;
    }

    /**
     * Add idReglement
     *
     * @param \alldevs\IfocopBundle\Entity\Reglement $idReglement
     * @return Stagiaires
     */
    public function addIdReglement(\alldevs\IfocopBundle\Entity\Reglement $idReglement)
    {
        $this->idReglement[] = $idReglement;
    
        return $this;
    }

    /**
     * Remove idReglement
     *
     * @param \alldevs\IfocopBundle\Entity\Reglement $idReglement
     */
    public function removeIdReglement(\alldevs\IfocopBundle\Entity\Reglement $idReglement)
    {
        $this->idReglement->removeElement($idReglement);
    }

    /**
     * Get idReglement
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdReglement()
    {
        return $this->idReglement;
    }

    /**
     * Set idFormations
     *
     * @param \alldevs\IfocopBundle\Entity\Formations $idFormations
     * @return Stagiaires
     */
    public function setIdFormations(\alldevs\IfocopBundle\Entity\Formations $idFormations = null)
    {
        $this->idFormations = $idFormations;
    
        return $this;
    }

    /**
     * Get idFormations
     *
     * @return \alldevs\IfocopBundle\Entity\Formations 
     */
    public function getIdFormations()
    {
        return $this->idFormations;
    }

    /**
     * Add idFacture
     *
     * @param \alldevs\IfocopBundle\Entity\Facture $idFacture
     * @return Stagiaires
     */
    public function addIdFacture(\alldevs\IfocopBundle\Entity\Facture $idFacture)
    {
        $this->idFacture[] = $idFacture;
    
        return $this;
    }

    /**
     * Remove idFacture
     *
     * @param \alldevs\IfocopBundle\Entity\Facture $idFacture
     */
    public function removeIdFacture(\alldevs\IfocopBundle\Entity\Facture $idFacture)
    {
        $this->idFacture->removeElement($idFacture);
    }

    /**
     * Get idFacture
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdFacture()
    {
        return $this->idFacture;
    }

    /**
     * Set nbrheure
     *
     * @param string $nbrheure
     * @return Stagiaires
     */
    public function setNbrheure($nbrheure)
    {
        $this->nbrheure = $nbrheure;
    
        return $this;
    }

    /**
     * Get nbrheure
     *
     * @return string 
     */
    public function getNbrheure()
    {
        return $this->nbrheure;
    }

    /**
     * Set typeannee
     *
     * @param integer $typeannee
     * @return Stagiaires
     */
    public function setTypeannee($typeannee)
    {
        $this->typeannee = $typeannee;
    
        return $this;
    }

    /**
     * Get typeannee
     *
     * @return integer 
     */
    public function getTypeannee()
    {
        return $this->typeannee;
    }

    /**
     * Set datedebut
     *
     * @param \DateTime $datedebut
     * @return Stagiaires
     */
    public function setDatedebut($datedebut)
    {
        $this->datedebut = $datedebut;
    
        return $this;
    }

    /**
     * Get datedebut
     *
     * @return \DateTime 
     */
    public function getDatedebut()
    {
        return $this->datedebut;
    }

    /**
     * Set datefin
     *
     * @param \DateTime $datefin
     * @return Stagiaires
     */
    public function setDatefin($datefin)
    {
        $this->datefin = $datefin;
    
        return $this;
    }

    /**
     * Get datefin
     *
     * @return \DateTime 
     */
    public function getDatefin()
    {
        return $this->datefin;
    }

    /**
     * Set dateannee
     *
     * @param integer $dateannee
     * @return Stagiaires
     */
    public function setDateannee($dateannee)
    {
        $this->dateannee = $dateannee;
    
        return $this;
    }

    /**
     * Get dateannee
     *
     * @return integer 
     */
    public function getDateannee()
    {
        return $this->dateannee;
    }
}